//*****************************************************************************
//*****************************************************************************
//  FILENAME: CAN.h
//   Version: 1.50, Updated on 2014/7/14 at 8:11:19
//
//  DESCRIPTION:  C declarations for the DelSig User Module with a 2nd-order
//                modulator based on a type-2 dcecimator
//-----------------------------------------------------------------------------
//      Copyright (c) Cypress Semiconductor 2014. All Rights Reserved.
//*****************************************************************************
//*****************************************************************************
#ifndef CAN_INCLUDE
#define CAN_INCLUDE

#include <m8c.h>

#pragma fastcall16 CAN_Start
#pragma fastcall16 CAN_SetPower
#pragma fastcall16 CAN_StartAD
#pragma fastcall16 CAN_StopAD
#pragma fastcall16 CAN_Stop
#pragma fastcall16 CAN_fIsDataAvailable
#pragma fastcall16 CAN_iGetData
#pragma fastcall16 CAN_wGetData
#pragma fastcall16 CAN_iGetDataClearFlag
#pragma fastcall16 CAN_wGetDataClearFlag
#pragma fastcall16 CAN_ClearFlag
#pragma fastcall16 CAN_WritePulseWidth

//-------------------------------------------------
// Prototypes of the CAN API.
//-------------------------------------------------
extern void CAN_Start(BYTE bPower);
extern void CAN_SetPower(BYTE bPower);
extern void CAN_StartAD(void);
extern void CAN_StopAD(void);
extern void CAN_Stop(void);
extern BOOL CAN_fIsDataAvailable(void);
extern INT  CAN_iGetData(void);
extern WORD CAN_wGetData(void);
extern INT  CAN_iGetDataClearFlag(void);
extern WORD CAN_wGetDataClearFlag(void);
extern void CAN_ClearFlag(void);
extern void CAN_WritePulseWidth(BYTE wPulseWidthValue);

//-------------------------------------------------
// Defines for CAN API's.
//-------------------------------------------------
#define CAN_OFF                            (0)
#define CAN_LOWPOWER                       (1)
#define CAN_MEDPOWER                       (2)
#define CAN_HIGHPOWER                      (3)

#define CAN_DATA_READY_BIT                 (0x10)
#define CAN_2S_COMPLEMENT                  (0)

//-------------------------------------------------
// Hardware Register Definitions
//-------------------------------------------------

#pragma ioport  CAN_PWM_DR0:    0x020               //Time base Counter register
BYTE            CAN_PWM_DR0;
#pragma ioport  CAN_PWM_DR1:    0x021               //Time base Period value register
BYTE            CAN_PWM_DR1;
#pragma ioport  CAN_PWM_DR2:    0x022               //Time base CompareValue register
BYTE            CAN_PWM_DR2;
#pragma ioport  CAN_PWM_CR0:    0x023               //Time base Control register
BYTE            CAN_PWM_CR0;
#pragma ioport  CAN_PWM_FN: 0x120                //Time base Function register
BYTE            CAN_PWM_FN;
#pragma ioport  CAN_PWM_SL: 0x121                //Time base Input register
BYTE            CAN_PWM_SL;
#pragma ioport  CAN_PWM_OS: 0x122                //Time base Output register
BYTE            CAN_PWM_OS;

#pragma ioport  CAN_AtoD1cr0:   0x080              //Analog block 1 control register 0
BYTE            CAN_AtoD1cr0;
#pragma ioport  CAN_AtoD1cr1:   0x081              //Analog block 1 control register 1
BYTE            CAN_AtoD1cr1;
#pragma ioport  CAN_AtoD1cr2:   0x082              //Analog block 1 control register 2
BYTE            CAN_AtoD1cr2;
#pragma ioport  CAN_AtoD1cr3:   0x083              //Analog block 1 control register 3
BYTE            CAN_AtoD1cr3;
#pragma ioport  CAN_AtoD2cr0:   0x090              //Analog block 2 control register 0
BYTE            CAN_AtoD2cr0;
#pragma ioport  CAN_AtoD2cr1:   0x091              //Analog block 2 control register 1
BYTE            CAN_AtoD2cr1;
#pragma ioport  CAN_AtoD2cr2:   0x092              //Analog block 2 control register 2
BYTE            CAN_AtoD2cr2;
#pragma ioport  CAN_AtoD2cr3:   0x093              //Analog block 2 control register 3
BYTE            CAN_AtoD2cr3;

#endif
// end of file CAN.h
