;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: CANINT.asm
;;   Version: 1.50, Updated on 2014/7/14 at 8:11:19
;;  Generated by PSoC Designer 5.4.2946
;;
;;  DESCRIPTION: Assembler interrupt service routine for the Delta-Sigma ADC
;;               User Module based on the Type 2 Decimator. This code works for
;;               both the first and second-order modulator topologies where
;;               the decimation rate requires no extra shift of the data
;;               in software.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2014. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "CAN.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export _CAN_ADConversion_ISR
export _CAN_iResult
export  CAN_iResult
export _CAN_bfStatus
export  CAN_bfStatus


;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------
AREA InterruptRAM (RAM, REL, CON)

_CAN_iResult:
 CAN_iResult:                      blk 2             ;ADC output value
_CAN_bfStatus:
 CAN_bfStatus:                     blk 1             ;Data Valid Flag


;-----------------------------------------------
;  Private Symbols
;-----------------------------------------------
MSB:                               equ 0
LSB:                               equ 1
RES:                               equ 10
UMAX:                              equ (1<<RES) - 1  ; 2^RES - 1


;@PSoC_UserCode_INIT@ (Do not change this line.)
;---------------------------------------------------
; Insert your custom declarations below this banner
;---------------------------------------------------

;------------------------
; Includes
;------------------------

;------------------------
; Exports
;------------------------

;------------------------
; Constant Definitions
;------------------------

;------------------------
; Variable Allocation
;------------------------

;---------------------------------------------------
; Insert your custom declarations above this banner
;---------------------------------------------------
;@PSoC_UserCode_END@ (Do not change this line.)


AREA UserModules (ROM, REL, CON)

;;=============================================================================
;;  FUNCTION NAME: _CAN_ADConversion_ISR:
;;=============================================================================
;;
_CAN_ADConversion_ISR:
   push  A
.ClrTst:
   M8C_ClearIntFlag CAN_INT_CLR_REG, CAN_INT_MASK
   mov   A, reg[DEC_DH]
   cmp   A, >(UMAX+1)                            ; Is value >= 2^RES?
   jc    .NoOverflow                             ;    No, Data is in normal range
   mov   A, reg[DEC_DL]
   mov   [CAN_iResult+MSB], >UMAX                ;   Yes, limit to 2^RES - 1
   mov   [CAN_iResult+LSB], <UMAX                ;          as expected
   jmp   .ConversionReady

.NoOverflow:
   mov   [CAN_iResult+MSB], A
   mov   A, reg[DEC_DL]
   mov   [CAN_iResult+LSB], A

.ConversionReady:
   tst   reg[CAN_INT_CLR_REG], CAN_INT_MASK
   jnz   .ClrTst
IF CAN_2S_COMPLEMENT
   ; Internal hardware format is unsigned; optionally convert so zero is half scale
   sub   [CAN_iResult+MSB], >(UMAX+1)>>1
ENDIF
   mov [CAN_bfStatus], CAN_DATA_READY_BIT                      

   ;@PSoC_UserCode_BODY@ (Do not change this line.)
   ;---------------------------------------------------
   ; Insert your custom code below this banner
   ;---------------------------------------------------


   ;---------------------------------------------------
   ; Insert your custom code above this banner
   ;---------------------------------------------------
   ;@PSoC_UserCode_END@ (Do not change this line.)

   pop A
   reti

; end of file CANINT.asm
